@@ -19,6 +19,8 @@
 #include <gio/gio.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <libpanel-util/panel-glib.h>
+
 #include "panel.h"
 
 #include "applet.h"
@@ -463,7 +465,8 @@ drop_url (PanelWidget *panel,
 		return FALSE;
 
 	netscape_url = g_strsplit (url, "\n", 2);
-	if (!netscape_url || string_empty (netscape_url[NETSCAPE_URL_URL])) {
+	if (!netscape_url ||
+	    PANEL_GLIB_STR_EMPTY (netscape_url[NETSCAPE_URL_URL])) {
 		g_strfreev (netscape_url);
 		return FALSE;
 	}
@@ -471,7 +474,7 @@ drop_url (PanelWidget *panel,
 	comment = g_strdup_printf (_("Open URL: %s"),
 				   netscape_url[NETSCAPE_URL_URL]);
 
-	if (string_empty (netscape_url[NETSCAPE_URL_NAME]))
+	if (PANEL_GLIB_STR_EMPTY (netscape_url[NETSCAPE_URL_NAME]))
 		name = netscape_url[NETSCAPE_URL_URL];
 	else
 		name = netscape_url[NETSCAPE_URL_NAME];
@@ -524,6 +527,13 @@ drop_uri (PanelWidget *panel,
 	if (!icon)
 		icon = g_strdup (fallback_icon);
 
+	/* FIXME: we might get icons like "folder-music" that might not exist in
+	 * the icon theme. This would usually be okay if we could use fallback
+	 * icons (and get "folder" this way). However, this is not possible for
+	 * launchers: this could be an application that uses an icon named
+	 * folder-magic-app, for which we don't want fallbacks. We just want to
+	 * go to hicolor. */
+
 	file = g_file_new_for_uri (uri);
 	buf = g_file_get_parse_name (file);
 	g_object_unref (file);
@@ -1310,10 +1320,10 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 			GTK_DIALOG_MODAL,
 			GTK_MESSAGE_WARNING,
 			GTK_BUTTONS_NONE,
-			text1);
+			"%s", text1);
 	
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-	                                          text2);	
+	                                          "%s", text2);	
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_DELETE, GTK_RESPONSE_OK,
